@@ -1,3 +1,5 @@
+# flask_secret_keys wordlist shamelessly copied from https://github.com/Paradoxis/Flask-Unsign <3 <3 <3
+
 import re
 from flask_unsign import verify as flaskVerify
 from badsecrets.base import BadsecretsBase
@@ -10,7 +12,9 @@ class Flask_SignedCookies(BadsecretsBase):
     def check_secret(self, flask_cookie):
         if not self.identify(flask_cookie):
             return None
-        for l in self.load_resource("top_10000_passwords.txt"):
+        for l in set(
+            list(self.load_resource("flask_secret_keys.txt")) + list(self.load_resource("top_10000_passwords.txt"))
+        ):
             password = l.rstrip()
             r = flaskVerify(value=flask_cookie, secret=password)
             if r:
